Crate cosmian_findex_client

Crate cosmian_findex_client 

Modules

reexport

Macros

client_bail
Return early with an error if a condition is not satisfied.
client_error
Construct a server error from a string.

Structs

FindexRestClient
KmsEncryptionLayer
The encryption layers is built on top of an encrypted memory implementing the MemoryADT and exposes a plaintext virtual memory interface implementing the MemoryADT.
RestClient
RestClientConfig

Enums

ClientError

Type Aliases

ClientResult