Modules
Macros
- client_
bail - Return early with an error if a condition is not satisfied.
- client_
error - Construct a server error from a string.
Structs
- Findex
Rest Client - KmsEncryption
Layer - The encryption layers is built on top of an encrypted memory implementing the
MemoryADTand exposes a plaintext virtual memory interface implementing theMemoryADT. - Rest
Client - Rest
Client Config